Learn R Programming

opinAr (version 1.0.0)

compute_icg: Computa el ICG (Compute ICG)

Description

Función para computar resultados del ICG (Function to compute ICG results)

Usage

compute_icg(data, wave = NULL, segment_by = NULL)

Value

devuelve un tibble con class "tbl_df","tbl", "data.frame" con el valor del ICG y de cada una de sus dimensiones por una o más olas y segmentado por las variables deseadas (returns a tibble with class "tbl_df", "tbl", "data.frame" with the value of the ICG and the dimensions for one or more waves and segmented by desired variables).

Arguments

data

un tibble guardado como objeto en el enviroment luego de consultar get_icg_raw (A tibble saved as an object in the enviroment after querying get_icg_raw).

wave

es el número de ola para la que se quiere computar el ICG (number of wave to which compute the ICG).

segment_by

parámetro para computar el ICG segmentado por distintas variables (parameter to compute ICG segmented by different variables).

See Also

get_icg_raw